==> timemory-3.1.0rc4.tar.gz: timemory-3.1.0rc4/source/timemory/variadic/definition.hpp <==
// MIT License
//
// Copyright (c) 2020, The Regents of the University of California,
// through Lawrence Berkeley National Laboratory (subject to receipt of any
// required approvals from the U.S. Dept. of Energy).  All rights reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#pragma once

#include "timemory/variadic/macros.hpp"
#include "timemory/variadic/types.hpp"
//
#include "timemory/variadic/auto_bundle.hpp"
#include "timemory/variadic/auto_hybrid.hpp"
#include "timemory/variadic/auto_list.hpp"
#include "timemory/variadic/auto_tuple.hpp"
#include "timemory/variadic/base_bundle.hpp"
#include "timemory/variadic/component_bundle.hpp"
#include "timemory/variadic/component_hybrid.hpp"
#include "timemory/variadic/component_list.hpp"
#include "timemory/variadic/component_tuple.hpp"
#include "timemory/variadic/functional.hpp"
#include "timemory/variadic/lightweight_tuple.hpp"
//
//  Implementations
//
#include "timemory/variadic/component_bundle.cpp"
#include "timemory/variadic/component_hybrid.cpp"
#include "timemory/variadic/component_list.cpp"
#include "timemory/variadic/component_tuple.cpp"
#include "timemory/variadic/lightweight_tuple.cpp"

==> timemory-3.2.1rc3.tar.gz: timemory-3.2.1rc3/source/timemory/variadic/definition.hpp <==
// MIT License
//
// Copyright (c) 2020, The Regents of the University of California,
// through Lawrence Berkeley National Laboratory (subject to receipt of any
// required approvals from the U.S. Dept. of Energy).  All rights reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#pragma once

#include "timemory/variadic/bundle_execute.hpp"
#include "timemory/variadic/macros.hpp"
#include "timemory/variadic/types.hpp"
//
#include "timemory/variadic/auto_base_bundle.hpp"
#include "timemory/variadic/auto_bundle.hpp"
#include "timemory/variadic/auto_list.hpp"
#include "timemory/variadic/auto_tuple.hpp"
#include "timemory/variadic/base_bundle.hpp"
#include "timemory/variadic/component_bundle.hpp"
#include "timemory/variadic/component_list.hpp"
#include "timemory/variadic/component_tuple.hpp"
#include "timemory/variadic/functional.hpp"
#include "timemory/variadic/impl.hpp"
#include "timemory/variadic/lightweight_tuple.hpp"
//
#if defined(TIMEMORY_USE_DEPRECATED)
#    include "timemory/variadic/auto_hybrid.hpp"
#    include "timemory/variadic/component_hybrid.hpp"
#endif
//
//  Implementations
//
#include "timemory/variadic/auto_base_bundle.cpp"
#include "timemory/variadic/functional.cpp"
#include "timemory/variadic/lightweight_tuple.cpp"
//
